# coding: utf-8

"""
Code generated by OpenAPI Generator (https://openapi-generator.tech), manual changes will be lost - read more on https://github.com/algolia/api-clients-automation. DO NOT EDIT.
"""

# The version of the algoliasearch package
__version__ = "4.21.0"


from .advanced_syntax_features import AdvancedSyntaxFeatures
from .alternatives_as_exact import AlternativesAsExact
from .around_precision import AroundPrecision
from .around_radius import AroundRadius
from .around_radius_all import AroundRadiusAll
from .auto_facet_filter import AutoFacetFilter
from .banner import Banner
from .banner_image import BannerImage
from .banner_image_url import BannerImageUrl
from .banner_link import BannerLink
from .boolean_string import BooleanString
from .bought_together_query import BoughtTogetherQuery
from .condition import Condition
from .consequence import Consequence
from .deleted_at_response import DeletedAtResponse
from .distinct import Distinct
from .error_base import ErrorBase
from .exact_on_single_word_query import ExactOnSingleWordQuery
from .exhaustive import Exhaustive
from .facet_filters import FacetFilters
from .facet_ordering import FacetOrdering
from .facet_stats import FacetStats
from .fallback_params import FallbackParams
from .fbt_model import FbtModel
from .get_recommend_task_response import GetRecommendTaskResponse
from .get_recommendations_params import GetRecommendationsParams
from .get_recommendations_response import GetRecommendationsResponse
from .hide_consequence_object import HideConsequenceObject
from .highlight_result import HighlightResult
from .highlight_result_option import HighlightResultOption
from .ignore_plurals import IgnorePlurals
from .index_settings_facets import IndexSettingsFacets
from .inside_bounding_box import InsideBoundingBox
from .looking_similar_model import LookingSimilarModel
from .looking_similar_query import LookingSimilarQuery
from .match_level import MatchLevel
from .matched_geo_location import MatchedGeoLocation
from .numeric_filters import NumericFilters
from .optional_filters import OptionalFilters
from .optional_words import OptionalWords
from .params_consequence import ParamsConsequence
from .personalization import Personalization
from .promote_consequence_object import PromoteConsequenceObject
from .query_type import QueryType
from .range import Range
from .ranking_info import RankingInfo
from .re_ranking_apply_filter import ReRankingApplyFilter
from .recommend_hit import RecommendHit
from .recommend_models import RecommendModels
from .recommend_rule import RecommendRule
from .recommend_search_params import RecommendSearchParams
from .recommend_updated_at_response import RecommendUpdatedAtResponse
from .recommendations_hit import RecommendationsHit
from .recommendations_request import RecommendationsRequest
from .recommendations_results import RecommendationsResults
from .redirect import Redirect
from .redirect_rule_index_data import RedirectRuleIndexData
from .redirect_rule_index_metadata import RedirectRuleIndexMetadata
from .redirect_url import RedirectURL
from .related_model import RelatedModel
from .related_query import RelatedQuery
from .remove_stop_words import RemoveStopWords
from .remove_words_if_no_results import RemoveWordsIfNoResults
from .rendering_content import RenderingContent
from .rule_metadata import RuleMetadata
from .search_recommend_rules_params import SearchRecommendRulesParams
from .search_recommend_rules_response import SearchRecommendRulesResponse
from .snippet_result import SnippetResult
from .snippet_result_option import SnippetResultOption
from .sort_remaining_by import SortRemainingBy
from .supported_language import SupportedLanguage
from .tag_filters import TagFilters
from .task_status import TaskStatus
from .time_range import TimeRange
from .trending_facet_hit import TrendingFacetHit
from .trending_facets_model import TrendingFacetsModel
from .trending_facets_query import TrendingFacetsQuery
from .trending_items_model import TrendingItemsModel
from .trending_items_query import TrendingItemsQuery
from .typo_tolerance import TypoTolerance
from .typo_tolerance_enum import TypoToleranceEnum
from .value import Value
from .widgets import Widgets

__all__ = (
    "AdvancedSyntaxFeatures",
    "AlternativesAsExact",
    "AroundPrecision",
    "AroundRadius",
    "AroundRadiusAll",
    "AutoFacetFilter",
    "Banner",
    "BannerImage",
    "BannerImageUrl",
    "BannerLink",
    "BooleanString",
    "BoughtTogetherQuery",
    "Condition",
    "Consequence",
    "DeletedAtResponse",
    "Distinct",
    "ErrorBase",
    "ExactOnSingleWordQuery",
    "Exhaustive",
    "FacetFilters",
    "FacetOrdering",
    "FacetStats",
    "FallbackParams",
    "FbtModel",
    "GetRecommendTaskResponse",
    "GetRecommendationsParams",
    "GetRecommendationsResponse",
    "HideConsequenceObject",
    "HighlightResult",
    "HighlightResultOption",
    "IgnorePlurals",
    "IndexSettingsFacets",
    "InsideBoundingBox",
    "LookingSimilarModel",
    "LookingSimilarQuery",
    "MatchLevel",
    "MatchedGeoLocation",
    "NumericFilters",
    "OptionalFilters",
    "OptionalWords",
    "ParamsConsequence",
    "Personalization",
    "PromoteConsequenceObject",
    "QueryType",
    "Range",
    "RankingInfo",
    "ReRankingApplyFilter",
    "RecommendHit",
    "RecommendModels",
    "RecommendRule",
    "RecommendSearchParams",
    "RecommendUpdatedAtResponse",
    "RecommendationsHit",
    "RecommendationsRequest",
    "RecommendationsResults",
    "Redirect",
    "RedirectRuleIndexData",
    "RedirectRuleIndexMetadata",
    "RedirectURL",
    "RelatedModel",
    "RelatedQuery",
    "RemoveStopWords",
    "RemoveWordsIfNoResults",
    "RenderingContent",
    "RuleMetadata",
    "SearchRecommendRulesParams",
    "SearchRecommendRulesResponse",
    "SnippetResult",
    "SnippetResultOption",
    "SortRemainingBy",
    "SupportedLanguage",
    "TagFilters",
    "TaskStatus",
    "TimeRange",
    "TrendingFacetHit",
    "TrendingFacetsModel",
    "TrendingFacetsQuery",
    "TrendingItemsModel",
    "TrendingItemsQuery",
    "TypoTolerance",
    "TypoToleranceEnum",
    "Value",
    "Widgets",
)
